@@ -1,7 +1,3 @@
-{% macro synapse__information_schema_name(database) -%}
-  {{ return(sqlserver__information_schema_name(database)) }}
-{%- endmacro %}
-
 {% macro synapse__get_columns_in_query(select_sql) %}
     {% call statement('get_columns_in_query', fetch_result=True, auto_begin=False) -%}
         select TOP 0 * from (
@@ -12,11 +8,29 @@
 {% endmacro %}
 
 {% macro synapse__list_relations_without_caching(schema_relation) %}
-  {{ return(sqlserver__list_relations_without_caching(schema_relation)) }}
+  {% call statement('list_relations_without_caching', fetch_result=True) -%}
+    select
+      table_catalog as [database],
+      table_name as [name],
+      table_schema as [schema],
+      case when table_type = 'BASE TABLE' then 'table'
+           when table_type = 'VIEW' then 'view'
+           else table_type
+      end as table_type
+
+    from information_schema.tables
+    where table_schema like '{{ schema_relation.schema }}'
+      and table_catalog like '{{ schema_relation.database }}'
+  {% endcall %}
+  {{ return(load_result('list_relations_without_caching').table) }}
 {% endmacro %}
  
 {% macro synapse__list_schemas(database) %}
-  {{ return(sqlserver__list_schemas(database)) }}
+  {% call statement('list_schemas', fetch_result=True, auto_begin=False) -%}
+    select  name as [schema]
+    from sys.schemas
+  {% endcall %}
+  {{ return(load_result('list_schemas').table) }}
 {% endmacro %}
 
 {% macro synapse__create_schema(relation) -%}
@@ -28,38 +42,25 @@
   {% endcall %}
 {% endmacro %}
 
-{% macro synapse__drop_schema(relation) -%}
-    {%- set tables_in_schema_query %}
-      SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES
-      WHERE TABLE_SCHEMA = '{{ relation.schema }}'
-  {% endset %}
-  {% set tables_to_drop = run_query(tables_in_schema_query).columns[0].values() %}
-  {% for table in tables_to_drop %}
-    {%- set schema_relation = adapter.get_relation(database=relation.database,
-                                               schema=relation.schema,
-                                               identifier=table) -%}
-    {% do drop_relation(schema_relation) %}
-  {%- endfor %}
-
-  {% call statement('drop_schema') -%}
-      IF EXISTS (SELECT * FROM sys.schemas WHERE name = '{{ relation.schema }}')
-      BEGIN
-      EXEC('DROP SCHEMA {{ relation.schema }}')
-      END  {% endcall %}
-{% endmacro %}
-
-{# TODO make this function just a wrapper of synapse__drop_relation_script #}
 {% macro synapse__drop_relation(relation) -%}
-  {{ return(sqlserver__drop_relation(relation)) }}
+  {% call statement('drop_relation', auto_begin=False) -%}
+    {{ synapse__drop_relation_script(relation) }}
+  {%- endcall %}
 {% endmacro %}
 
 {% macro synapse__drop_relation_script(relation) -%}
-  {{ return(sqlserver__drop_relation_script(relation)) }}
+  {% if relation.type == 'view' -%}
+    {% set object_id_type = 'V' %}
+  {% elif relation.type == 'table'%}
+    {% set object_id_type = 'U' %}
+  {%- else -%} invalid target name
+  {% endif %}
+  if object_id ('{{ relation.include(database=False) }}','{{ object_id_type }}') is not null
+    begin
+    drop {{ relation.type }} {{ relation.include(database=False) }}
+    end
 {% endmacro %}
 
-{% macro synapse__check_schema_exists(information_schema, schema) -%}
-  {{ return(sqlserver__check_schema_exists(information_schema, schema)) }}
-{% endmacro %}
 
 {% macro synapse__create_view_as(relation, sql) -%}
   create view {{ relation.include(database=False) }} as
@@ -115,14 +116,6 @@
 
 {% endmacro %}
 
-{% macro synapse__insert_into_from(to_relation, from_relation) -%}
-  {{ return(sqlserver__insert_into_from(to_relation, from_relation)) }}
-{% endmacro %}
-
-{% macro synapse__current_timestamp() -%}
-  {{ return(sqlserver__current_timestamp()) }}
-{%- endmacro %}
-
 {% macro synapse__get_columns_in_relation(relation) -%}
   {# hack because tempdb has no infoschema see: #}
   {# https://stackoverflow.com/questions/63800841/get-column-names-of-temp-table-in-azure-synapse-dw #}
@@ -133,8 +126,15 @@
 
     {% do  drop_relation(tmp_tbl_hack) %}
     {% set sql_create %}
+        CREATE TABLE {{ tmp_tbl_hack }}
+        WITH(
+          -- Always use a round-robin heap, since columns with types like varbinaries
+          -- cannot be part of a clustered column store, which is the default index
+          DISTRIBUTION = ROUND_ROBIN,
+          HEAP
+        )
+        AS
         SELECT TOP(1) * 
-        INTO {{tmp_tbl_hack}}
         FROM {{relation}}
     {% endset %}
     {% call statement() -%} {{ sql_create }} {%- endcall %}
@@ -158,11 +158,3 @@
   {% set table = load_result('get_columns_in_relation').table %}
   {{ return(sql_convert_columns_in_relation(table)) }}
 {% endmacro %}
-
-{% macro synapse__make_temp_relation(base_relation, suffix) %}
-  {{ return(sqlserver__make_temp_relation(base_relation, suffix)) }}
-{% endmacro %}
-
-{% macro synapse__snapshot_string_as_time(timestamp) -%}
-  {{ return(sqlserver__snapshot_string_as_time(timestamp)) }}
-{%- endmacro %}
\ No newline at end of file
